@@ -17,7 +17,9 @@ RGB_DIR = "rgb"
 
 
 def _copy_images_by_dict(
-    faces_paths: List[List[Path]], input_dir: Path, output_dir: Path,
+    faces_paths: List[List[Path]],
+    input_dir: Path,
+    output_dir: Path,
 ):
     for num, img_paths in track(
         enumerate(faces_paths), "Saving...", total=len(faces_paths)
@@ -37,7 +39,10 @@ def _copy_images_by_dict(
             dst_rgb = path_rgb / rgb_name
             dst_ir = path_ir / ir_name
             shutil.copyfile(img_path, dst_rgb)
-            shutil.copyfile(input_dir / IR_DIR / ir_name, dst_ir)
+            try:
+                shutil.copyfile(input_dir / IR_DIR / ir_name, dst_ir)
+            except FileNotFoundError as error:
+                print(error)
 
 
 def _get_timestamp(name: str) -> str:
@@ -69,15 +74,14 @@ def _np_pop(array: np.ndarray) -> Tuple[Any, np.ndarray]:
 
 
 def _get_encodings_from_image_dir(
-    input_dir: Path, verbose: bool
+    input_dir: Path, verbose: bool, model="hog"
 ) -> Tuple[np.ndarray, np.ndarray]:
     """Извлекает энкодинги и возвращает вместе с путями"""
     face_encs: List[np.ndarray] = []
     face_path = []
-    for img_path in track(image_files_in_folder(input_dir / RGB_DIR),
-                          "Processing..."):
+    for img_path in track(image_files_in_folder(input_dir / RGB_DIR), "Processing..."):
         image = load_image_file(img_path)
-        face_bounding_boxes = face_locations(image)
+        face_bounding_boxes = face_locations(image, model)
 
         if len(face_bounding_boxes) != 1:
             # If there are no people (or too many people) in a training image,
